def task_checker():
    return {'actions': ["pychecker sample.py"],
            'file_dep': ["sample.py"]}
